// Copyright 2017 The Chromium Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.

package com.qpc.qpc_admob;

import android.os.Bundle;
import android.util.Log;

import com.bytedance.sdk.openadsdk.AdSlot;

import java.util.ArrayList;
import java.util.Date;
import java.util.List;
import java.util.Map;

class AdRequestBuilderFactory {

  private static final String TAG = "flutter";
  private final Map<String, Object> targetingInfo;

  AdRequestBuilderFactory(Map<String, Object> targetingInfo) {
    this.targetingInfo = targetingInfo;
  }

  private String getTargetingInfoString(String key, Object value) {
    if (value == null) return null;
    if (!(value instanceof String)) {
      Log.w(TAG, "targeting info " + key + ": expected a String");
      return null;
    }
    String stringValue = (String) value;
    if (stringValue.isEmpty()) {
      Log.w(TAG, "targeting info " + key + ": expected a non-empty String");
      return null;
    }
    return stringValue;
  }

  private Boolean getTargetingInfoBoolean(String key, Object value) {
    if (value == null) return null;
    if (!(value instanceof Boolean)) {
      Log.w(TAG, "targeting info " + key + ": expected a boolean");
      return null;
    }
    return (Boolean) value;
  }

  private Integer getTargetingInfoInteger(String key, Object value) {
    if (value == null) return null;
    if (!(value instanceof Integer)) {
      Log.w(TAG, "targeting info " + key + ": expected an integer");
      return null;
    }
    return (Integer) value;
  }

  private List getTargetingInfoArrayList(String key, Object value) {
    if (value == null) return null;
    if (!(value instanceof ArrayList)) {
      Log.w(TAG, "targeting info " + key + ": expected an ArrayList");
      return null;
    }
    return (List) value;
  }

  AdSlot.Builder createAdRequestBuilder() {
    AdSlot.Builder builder = new  AdSlot.Builder();
    if (targetingInfo == null) return builder;
    return builder;
  }
}
