// Copyright 2017 The Chromium Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.

package com.qpc.qpc_admob;

import android.app.Activity;
import android.content.res.Configuration;
import android.graphics.Point;
import android.text.TextUtils;
import android.util.Log;
import android.view.View;
import android.view.View.OnClickListener;
import android.view.ViewGroup;
import android.widget.CheckBox;
import android.widget.CompoundButton;
import android.widget.EditText;
import android.widget.FrameLayout;
import android.widget.Toast;


import com.bytedance.sdk.openadsdk.AdSlot;
import com.bytedance.sdk.openadsdk.TTAdNative;
import com.qq.e.ads.banner2.UnifiedBannerADListener;
import com.qq.e.ads.banner2.UnifiedBannerView;
import com.qq.e.ads.interstitial2.UnifiedInterstitialAD;
import com.qq.e.ads.interstitial2.UnifiedInterstitialADListener;
import com.qq.e.ads.interstitial2.UnifiedInterstitialMediaListener;
import com.qq.e.comm.constants.AdPatternType;
import com.qq.e.comm.util.AdError;

import java.util.Locale;
import java.util.Map;

import io.flutter.plugin.common.MethodChannel;

abstract class TxMobileAd extends MobileAd  {

    private static final String TAG = "flutter";


    private TxMobileAd(int id, Activity activity, MethodChannel channel) {
     super(id,activity,channel);
    }

    static TxBanner createBanner(Integer id, String adUnitId, int width, int height, Activity activity, MethodChannel channel) {
        MobileAd ad = getAdForId(id);
        return (ad != null) ? (TxBanner) ad : new TxBanner(id,width,height,activity,channel);

    }

    static TxInterstitial createInterstitial(Integer id, Activity activity, MethodChannel channel) {
        MobileAd ad = getAdForId(id);
        return (ad != null) ? (TxInterstitial) ad : new TxInterstitial(id, activity, channel);
    }


    static class TxBanner extends TxMobileAd implements  OnClickListener,
            UnifiedBannerADListener, CompoundButton.OnCheckedChangeListener {

        private int width;
        private int height;
        private UnifiedBannerView bannerView;

        private TxBanner(Integer id, int width, int height, Activity activity, MethodChannel channel) {
            super(id, activity, channel);
            this.width = width;
            this.height = height;
        }


        @Override
        void load(String adUnitId, Map<String, Object> targetingInfo) {
            if (status != Status.CREATED) return;
            status = Status.LOADING;
            AdSlot adSlot = new AdSlot.Builder()
                    .setCodeId(adUnitId)
                    .setSupportDeepLink(true)
                    .setImageAcceptedSize(width, height)
                    .setAdCount(1)
                    .build();
            UnifiedBannerView bannerView = new UnifiedBannerView(activity, TxConsts.appId, adUnitId, this);
            bannerView.loadAD();
        }

        @Override
        void show() {
            if (status == Status.LOADING) {
                status = Status.PENDING;
                return;
            }
            if (status != Status.LOADED) return;

            if (activity.findViewById(id) == null) {

            }
        }

        @Override
        void dispose() {
            super.dispose();


            View contentView = activity.findViewById(id);
            if (contentView == null || !(contentView.getParent() instanceof ViewGroup)) return;

            ViewGroup contentParent = (ViewGroup) (contentView.getParent());
            contentParent.removeView(contentView);
        }


        @Override
        public void onClick(View v) {
//            switch (v.getId()) {
//                case R.id.refreshBanner:
//                    doRefreshBanner();
//                    break;
//                case R.id.closeBanner:
//                    doCloseBanner();
//                    break;
//                default:
//                    break;
//            }
        }


        @Override
        public void onNoAD(AdError adError) {
            String msg = String.format(Locale.getDefault(), "onNoAD, error code: %d, error msg: %s",
                    adError.getErrorCode(), adError.getErrorMsg());
            Toast.makeText(activity, msg, Toast.LENGTH_LONG).show();
        }

        @Override
        public void onADReceive() {
            Log.i(TAG, "onADReceive");
        }

        @Override
        public void onADExposure() {
            Log.i(TAG, "onADExposure");
        }

        @Override
        public void onADClosed() {
            Log.i(TAG, "onADClosed");
        }

        @Override
        public void onADClicked() {
            Log.i(TAG, "onADClicked : " + (bannerView.getExt() != null ? bannerView.getExt().get("clickUrl") : ""));
        }

        @Override
        public void onADLeftApplication() {
            Log.i(TAG, "onADLeftApplication");
        }

        @Override
        public void onADOpenOverlay() {
            Log.i(TAG, "onADOpenOverlay");
        }

        @Override
        public void onADCloseOverlay() {
            Log.i(TAG, "onADCloseOverlay");
        }

        @Override
        public void onCheckedChanged(CompoundButton buttonView, boolean isChecked) {
            if (this.bannerView != null) {
                if (isChecked) {
//                    try {
//                        int refreshInterval = Integer.parseInt(((EditText) findViewById(R.id.etRefreshInterval))
//                                .getText().toString());
//                        this.bv.setRefresh(refreshInterval);
//                        Toast.makeText(this, "轮播时间间隔设置为:" + refreshInterval, Toast.LENGTH_LONG).show();
//                    } catch (NumberFormatException e) {
//                        Toast.makeText(this, "请输入合法的轮播时间间隔!", Toast.LENGTH_LONG).show();
//                    }
//                } else {
//                    this.bv.setRefresh(30);
//                    Toast.makeText(this, "轮播时间间隔恢复默认", Toast.LENGTH_LONG).show();
//                }
//            } else {
//                Toast.makeText(this, "轮播时间间隔设置失败!", Toast.LENGTH_LONG).show();
//            }
                }
            }
        }
    }

    static class TxInterstitial extends TxMobileAd implements OnClickListener,
            UnifiedInterstitialADListener, UnifiedInterstitialMediaListener, CompoundButton.OnCheckedChangeListener {

        private UnifiedInterstitialAD iad;

        private TxInterstitial(int id, Activity activity, MethodChannel channel) {
            super(id, activity, channel);

        }

        @Override
        void load(String adUnitId, Map<String, Object> targetingInfo) {
            status = Status.LOADING;
            iad = new UnifiedInterstitialAD(activity, TxConsts.appId, adUnitId, this);
            iad.loadAD();
        }

        @Override
        void show() {
            if (status == Status.LOADING) {
                status = Status.PENDING;
                return;
            }
            if (iad != null) {
                iad.show();
            } else {
                Toast.makeText(activity, "请加载广告后再进行展示 ！ ", Toast.LENGTH_LONG).show();
            }

        }

        @Override
        public void onClick(View v) {
//            switch (v.getId()) {
//                case R.id.loadIAD:
//                    iad = getIAD();
//                    setVideoOption();
//                    iad.loadAD();
//                    break;
//                case R.id.showIAD:
//                    showAD();
//                    break;
//                case R.id.showIADAsPPW:
//                    showAsPopup();
//                    break;
//                case R.id.closeIAD:
//                    close();
//                    break;
//                default:
//                    break;
//            }
        }


        @Override
        public void onADReceive() {
            Toast.makeText(activity, "广告加载成功 ！ ", Toast.LENGTH_LONG).show();
            // onADReceive之后才能调用getAdPatternType()
            if (iad.getAdPatternType() == AdPatternType.NATIVE_VIDEO) {
                iad.setMediaListener(this);
            }
            // onADReceive之后才可调用getECPM()
            Log.d(TAG, "eCPM = " + iad.getECPM() + " , eCPMLevel = " + iad.getECPMLevel());
        }

        @Override
        public void onVideoCached() {
            // 视频素材加载完成，在此时调用iad.show()或iad.showAsPopupWindow()视频广告不会有进度条。
            Log.i(TAG, "onVideoCached");
        }

        @Override
        public void onNoAD(AdError error) {
            String msg = String.format(Locale.getDefault(), "onNoAD, error code: %d, error msg: %s",
                    error.getErrorCode(), error.getErrorMsg());
            Toast.makeText(activity, msg, Toast.LENGTH_LONG).show();
        }

        @Override
        public void onADOpened() {
            Log.i(TAG, "onADOpened");
        }

        @Override
        public void onADExposure() {
            Log.i(TAG, "onADExposure");
        }

        @Override
        public void onADClicked() {
            Log.i(TAG, "onADClicked : " + (iad.getExt() != null ? iad.getExt().get("clickUrl") : ""));
        }

        @Override
        public void onADLeftApplication() {
            Log.i(TAG, "onADLeftApplication");
        }

        @Override
        public void onADClosed() {
            Log.i(TAG, "onADClosed");
        }

        @Override
        public void onVideoInit() {
            Log.i(TAG, "onVideoInit");
        }

        @Override
        public void onVideoLoading() {
            Log.i(TAG, "onVideoLoading");
        }

        @Override
        public void onVideoReady(long videoDuration) {
            Log.i(TAG, "onVideoReady, duration = " + videoDuration);
        }

        @Override
        public void onVideoStart() {
            Log.i(TAG, "onVideoStart");
        }

        @Override
        public void onVideoPause() {
            Log.i(TAG, "onVideoPause");
        }

        @Override
        public void onVideoComplete() {
            Log.i(TAG, "onVideoComplete");
        }

        @Override
        public void onVideoError(AdError error) {
            Log.i(TAG, "onVideoError, code = " + error.getErrorCode() + ", msg = " + error.getErrorMsg());
        }

        @Override
        public void onVideoPageOpen() {
            Log.i(TAG, "onVideoPageOpen");
        }

        @Override
        public void onVideoPageClose() {
            Log.i(TAG, "onVideoPageClose");
        }

        @Override
        public void onCheckedChanged(CompoundButton buttonView, boolean isChecked) {
//            if(buttonView == btnNoOption){
//                btnMute.setEnabled(!isChecked);
//                btnDetailMute.setEnabled(!isChecked);
//                networkSpinner.setEnabled(!isChecked);
//            }else{
//                if (isChecked) {
//                    ((EditText) findViewById(R.id.posId)).setText(PositionId.UNIFIED_INTERSTITIAL_ID_LARGE_SMALL);
//                } else {
//                    ((EditText) findViewById(R.id.posId)).setText(PositionId.UNIFIED_INTERSTITIAL_ID_ONLY_SMALL);
//                }
//            }
//        }
        }
    }
}
