// Copyright 2017 The Chromium Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.

package com.qpc.qpc_admob;

import android.app.Activity;
import android.os.SystemClock;
import android.util.Log;
import android.widget.Button;
import android.widget.CompoundButton;
import android.widget.Toast;

import com.qq.e.ads.rewardvideo.RewardVideoAD;
import com.qq.e.ads.rewardvideo.RewardVideoADListener;
import com.qq.e.comm.util.AdError;

import java.util.Date;
import java.util.HashMap;
import java.util.Locale;
import java.util.Map;

import io.flutter.plugin.common.MethodChannel;

public class TxRewardedVideoAdWrapper implements RewardVideoADListener, CompoundButton.OnCheckedChangeListener {

  private static final String TAG = "qpc";

  private final MethodChannel channel;
  Activity activity;
  private Status status;
  private Button mLoadAdVertical;
  private Button mShowAd;
  private String mHorizontalCodeId;
  private String mVerticalCodeId;
  private boolean adLoaded;//广告加载成功标志
  private boolean videoCached;//视频素材文件下载完成标志
  private RewardVideoAD rewardVideoAD;



  enum Status {
    CREATED,
    LOADING,
    FAILED,
    LOADED
  }

  public TxRewardedVideoAdWrapper(Activity activity, MethodChannel channel) {
    this.activity= activity;
    this.channel = channel;
    this.status = Status.CREATED;


  }

  Status getStatus() {
    return status;
  }

  public void load(String adUnitId,String userId, Map<String, Object> targetingInfo) {
    status = Status.LOADING;
    rewardVideoAD = new RewardVideoAD(activity, TxConsts.appId, adUnitId, this);
    adLoaded = false;
    videoCached = false;
    rewardVideoAD.loadAD();


  }

  public void show() {
    if (adLoaded && rewardVideoAD != null)
    {//广告展示检查1：广告成功加载，此处也可以使用videoCached来实现视频预加载完成后再展示激励视频广告的逻辑
      if (!rewardVideoAD.hasShown()) {//广告展示检查2：当前广告数据还没有展示过
        long delta = 1000;//建议给广告过期时间加个buffer，单位ms，这里demo采用1000ms的buffer
        //广告展示检查3：展示广告前判断广告数据未过期
        if (SystemClock.elapsedRealtime() < (rewardVideoAD.getExpireTimestamp() - delta)) {
          rewardVideoAD.showAD();
        } else {
          Toast.makeText(activity, "激励视频广告已过期，请再次请求广告后进行广告展示！", Toast.LENGTH_LONG).show();
        }
      } else {
        Toast.makeText(activity, "此条广告已经展示过，请再次请求广告后进行广告展示！", Toast.LENGTH_LONG).show();
      }
    } else {
      Toast.makeText(activity, "成功加载广告后再进行广告展示！", Toast.LENGTH_LONG).show();
    }
  }

  private Map<String, Object> argumentsMap(Object... args) {
    Map<String, Object> arguments = new HashMap<String, Object>();
    for (int i = 0; i < args.length; i += 2) arguments.put(args[i].toString(), args[i + 1]);
    return arguments;
  }

  /**
   * 广告加载成功，可在此回调后进行广告展示
   **/
  @Override
  public void onADLoad() {
    adLoaded = true;
    String msg = "load ad success ! expireTime = " + new Date(System.currentTimeMillis() +
            rewardVideoAD.getExpireTimestamp() - SystemClock.elapsedRealtime());
    Toast.makeText(activity, msg, Toast.LENGTH_LONG).show();
    Log.d(TAG, "eCPM = " + rewardVideoAD.getECPM() + " , eCPMLevel = " + rewardVideoAD.getECPMLevel());
//    show();
  }

  /**
   * 视频素材缓存成功，可在此回调后进行广告展示
   */
  @Override
  public void onVideoCached() {
    videoCached = true;
    Log.i(TAG, "onVideoCached");
  }

  /**
   * 激励视频广告页面展示
   */
  @Override
  public void onADShow() {
    Log.i(TAG, "onADShow");
  }

  /**
   * 激励视频广告曝光
   */
  @Override
  public void onADExpose() {
    Log.i(TAG, "onADExpose");
  }

  /**
   * 激励视频触发激励（观看视频大于一定时长或者视频播放完毕）
   */
  @Override
  public void onReward() {
    Log.i(TAG, "onReward");
  }

  /**
   * 激励视频广告被点击
   */
  @Override
  public void onADClick() {
    Map<String, String> map = rewardVideoAD.getExts();
    String clickUrl = map.get("clickUrl");
    Log.i(TAG, "onADClick clickUrl: " + clickUrl);
  }

  /**
   * 激励视频播放完毕
   */
  @Override
  public void onVideoComplete() {
    Log.i(TAG, "onVideoComplete");
  }

  /**
   * 激励视频广告被关闭
   */
  @Override
  public void onADClose() {
    Log.i(TAG, "onADClose");
  }

  /**
   * 广告流程出错
   */
  @Override
  public void onError(AdError adError) {
    String msg = String.format(Locale.getDefault(), "onError, error code: %d, error msg: %s",
            adError.getErrorCode(), adError.getErrorMsg());
    Toast.makeText(activity, msg, Toast.LENGTH_LONG).show();
  }

  @Override
  public void onCheckedChanged(CompoundButton buttonView, boolean isChecked) {
//    if (isChecked) {
//      posId.setText(PositionId.REWARD_VIDEO_AD_POS_ID_SUPPORT_H);
//    } else {
//      posId.setText(PositionId.REWARD_VIDEO_AD_POS_ID_UNSUPPORT_H);
//    }
  }

}
